@@ -77,7 +77,7 @@ class ObfuscationClassifier:
         # convert batch of command strings into tensors
         x = torch.zeros(len(commands_list), len(self.char_dict) + 1, TENSOR_LENGTH).to(self.device)
         for i in range(len(commands_list)):
-            cmd = commands_list[i]
+            cmd = str(commands_list[i])
             tensor_len = min(TENSOR_LENGTH, len(cmd))
             for j in range(tensor_len):
                 char = cmd[j]
